from distutils.core import setup

setup(
		name 			='nester_list',
		version			='1.2.0',
		py_modules		=['nester_list'],
		author			='Jasmin Softic',
		author_email	='jasoftic@gmail.com',
		url				='http://www.sacgc.org',
		description		='A simple printer of nester lists',
	)




	